ProfileValidationResult

Struct ProfileValidationResult 

pub struct ProfileValidationResult {
    pub satisfied: bool,
    pub missing_ops: BTreeSet<OpKind>,
    pub missing_exprs: BTreeSet<ExprKind>,
}
Result of validating an engine’s capabilities against a ConformanceProfile.

Fields

satisfied: bool

Whether the engine’s capabilities fully satisfy the profile.

missing_ops: BTreeSet<OpKind>

Ops required by the profile that the engine does not declare.

missing_exprs: BTreeSet<ExprKind>

Exprs required by the profile that the engine does not declare.