pub struct ProfileValidationResult {
pub satisfied: bool,
pub missing_ops: BTreeSet<OpKind>,
pub missing_exprs: BTreeSet<ExprKind>,
}Expand description
Result of validating an engine’s capabilities against a ConformanceProfile.
Fields
satisfied: boolWhether the engine’s capabilities fully satisfy the profile.
missing_ops: BTreeSet<OpKind>Ops required by the profile that the engine does not declare.
missing_exprs: BTreeSet<ExprKind>Exprs required by the profile that the engine does not declare.